==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/LABELITEM.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LABELID">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;maxLength value="61"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element name="LABELVALUE" type="{http://schemas.datastream.net/MP_fields}CODE255_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "labelid",
    "labelvalue"
})
@XmlRootElement(name = "LABELITEM")
public class LABELITEM {

    @XmlElement(name = "LABELID", required = true)
    protected String labelid;
    @XmlElement(name = "LABELVALUE", required = true)
    protected String labelvalue;

    /**
     * Obtient la valeur de la propriété labelid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLABELID() {
        return labelid;
    }

    /**
     * Définit la valeur de la propriété labelid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLABELID(String value) {
        this.labelid = value;
    }

    /**
     * Obtient la valeur de la propriété labelvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLABELVALUE() {
        return labelvalue;
    }

    /**
     * Définit la valeur de la propriété labelvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLABELVALUE(String value) {
        this.labelvalue = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/LABELITEM.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LABELID">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;maxLength value="61"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element name="LABELVALUE" type="{http://schemas.datastream.net/MP_fields}CODE255_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "labelid",
    "labelvalue"
})
@XmlRootElement(name = "LABELITEM")
public class LABELITEM {

    @XmlElement(name = "LABELID", required = true)
    protected String labelid;
    @XmlElement(name = "LABELVALUE", required = true)
    protected String labelvalue;

    /**
     * Gets the value of the labelid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLABELID() {
        return labelid;
    }

    /**
     * Sets the value of the labelid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLABELID(String value) {
        this.labelid = value;
    }

    /**
     * Gets the value of the labelvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLABELVALUE() {
        return labelvalue;
    }

    /**
     * Sets the value of the labelvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLABELVALUE(String value) {
        this.labelvalue = value;
    }

}
